@@ -26,6 +26,7 @@ from robotcode.core.text_document import TextDocument
 from robotcode.core.uri import Uri
 from robotcode.core.utils.logging import LoggingDescriptor
 from robotcode.core.workspace import Workspace, WorkspaceFolder
+from robotcode.robot.diagnostics.diagnostics_modifier import DiagnosticModifiersConfig, DiagnosticsModifier
 
 from ..config.model import RobotBaseProfile
 from ..utils import get_robot_version
@@ -33,7 +34,13 @@ from ..utils.stubs import Languages
 from .imports_manager import ImportsManager
 from .library_doc import LibraryDoc
 from .namespace import DocumentType, Namespace
-from .workspace_config import AnalysisRobotConfig, CacheConfig, RobotConfig
+from .workspace_config import (
+    AnalysisDiagnosticModifiersConfig,
+    AnalysisRobotConfig,
+    CacheConfig,
+    RobotConfig,
+    WorkspaceAnalysisConfig,
+)
 
 
 class UnknownFileTypeError(Exception):
@@ -53,6 +60,7 @@ class DocumentsCacheHelper:
         documents_manager: DocumentsManager,
         file_watcher_manager: FileWatcherManagerBase,
         robot_profile: Optional[RobotBaseProfile],
+        analysis_config: Optional[WorkspaceAnalysisConfig],
     ) -> None:
         self.INITIALIZED_NAMESPACE = _CacheEntry()
 
@@ -61,6 +69,7 @@ class DocumentsCacheHelper:
         self.file_watcher_manager = file_watcher_manager
 
         self.robot_profile = robot_profile or RobotBaseProfile()
+        self.analysis_config = analysis_config or WorkspaceAnalysisConfig()
 
         self._imports_managers_lock = threading.RLock()
         self._imports_managers: weakref.WeakKeyDictionary[WorkspaceFolder, ImportsManager] = weakref.WeakKeyDictionary()
@@ -109,8 +118,7 @@ class DocumentsCacheHelper:
             except ValueError as e:
                 ex = e
                 self._logger.exception(
-                    lambda: f"Language configuration is not valid: {ex}"
-                    "\nPlease check your 'robotcode.robot.language' configuration.",
+                    lambda: f"Language configuration is not valid: {ex}",
                     exc_info=ex,
                     level=CRITICAL,
                 )
@@ -330,7 +338,7 @@ class DocumentsCacheHelper:
         if document_type == DocumentType.RESOURCE:
             return self.get_resource_model(document, data_only)
 
-        raise UnknownFileTypeError(f"Unknown file type '{document.uri}'.")
+        return self.get_general_model(document, data_only)
 
     def __get_model(
         self,
@@ -401,7 +409,16 @@ class DocumentsCacheHelper:
         return document.get_cache(self.__get_namespace)
 
     def __get_namespace(self, document: TextDocument) -> Namespace:
-        return self.__get_namespace_for_document_type(document, None)
+        document_type = self.get_document_type(document)
+
+        if document_type == DocumentType.INIT:
+            return self.get_init_namespace(document)
+        if document_type == DocumentType.RESOURCE:
+            return self.get_resource_namespace(document)
+        if document_type == DocumentType.GENERAL:
+            return self.get_general_namespace(document)
+
+        return self.__get_namespace_for_document_type(document, document_type)
 
     def get_resource_namespace(self, document: TextDocument) -> Namespace:
         return document.get_cache(self.__get_resource_namespace)
@@ -439,9 +456,6 @@ class DocumentsCacheHelper:
 
     def __namespace_initialized(self, sender: Namespace) -> None:
         if sender.document is not None:
-            self._logger.debug(
-                lambda: f"Save initialized Namespace: {sender.document.uri if sender.document else None}"
-            )
             sender.document.set_data(self.INITIALIZED_NAMESPACE, sender)
             self.namespace_initialized(self, sender)
 
@@ -453,9 +467,7 @@ class DocumentsCacheHelper:
         return result
 
     def get_only_initialized_namespace(self, document: TextDocument) -> Optional[Namespace]:
-        result: Optional[Namespace] = document.get_data(self.INITIALIZED_NAMESPACE)
-
-        return result
+        return cast(Optional[Namespace], document.get_data(self.INITIALIZED_NAMESPACE))
 
     def __get_namespace_for_document_type(
         self, document: TextDocument, document_type: Optional[DocumentType]
@@ -515,11 +527,16 @@ class DocumentsCacheHelper:
             variables,
             variable_files,
             environment,
-            cache_config.ignored_libraries,
-            cache_config.ignored_variables,
-            cache_config.ignore_arguments_for_library,
-            analysis_config.global_library_search_order,
+            self.analysis_config.cache.ignored_libraries + cache_config.ignored_libraries,
+            self.analysis_config.cache.ignored_variables + cache_config.ignored_variables,
+            self.analysis_config.cache.ignore_arguments_for_library + cache_config.ignore_arguments_for_library,
+            self.analysis_config.robot.global_library_search_order + analysis_config.global_library_search_order,
             cache_base_path,
+            load_library_timeout=(
+                analysis_config.load_library_timeout
+                if analysis_config.load_library_timeout is not None
+                else self.analysis_config.robot.load_library_timeout
+            ),
         )
 
         result.libraries_changed.add(self._on_libraries_changed)
@@ -577,5 +594,20 @@ class DocumentsCacheHelper:
             return self._imports_managers[folder]
 
     def calc_cache_path(self, folder_uri: Uri) -> Path:
-        # TODO: cache path should be configurable, save cache in vscode workspace folder or in robotcode cache folder
         return folder_uri.to_path()
+
+    def get_diagnostic_modifier(self, document: TextDocument) -> DiagnosticsModifier:
+        return document.get_cache(self.__get_diagnostic_modifier)
+
+    def __get_diagnostic_modifier(self, document: TextDocument) -> DiagnosticsModifier:
+        modifiers_config = self.workspace.get_configuration(AnalysisDiagnosticModifiersConfig, document.uri)
+        return DiagnosticsModifier(
+            self.get_model(document, False),
+            DiagnosticModifiersConfig(
+                ignore=self.analysis_config.modifiers.ignore + modifiers_config.ignore,
+                error=self.analysis_config.modifiers.error + modifiers_config.error,
+                warning=self.analysis_config.modifiers.warning + modifiers_config.warning,
+                information=self.analysis_config.modifiers.information + modifiers_config.information,
+                hint=self.analysis_config.modifiers.hint + modifiers_config.hint,
+            ),
+        )
